#example where amount, dry matter content, C and N content are known.
CN_input_amendments(40, DMC = 300, C_content = 300, N_content = 30)
#example where only amount and type of amendment are known
CN_input_amendments(20, "Manure_pig")
#example of a diluted slurry
CN_input_amendments(20, amd_type = "Slurry_dairy_cow", DMC = 50)
Run the code above in your browser using DataLab