Learn R Programming

SoilManageR (version 1.0.1)

CN_input_amendments_LUT: Look-up-table with default values to calculate C and N inputs by organic amendments

Description

The dataset is a look-up-table that is used to calculate the carbon (C) and nitrogen (N) inputs by organic amendments with the function `SoilManageR::CN_input_amendments()`. The data set is produced from the excel table `CN_input_amendments_LUT.xlsx` file under `/inst/extdata/`.

Usage

CN_input_amendments_LUT

Arguments

Format

A tibble with 27 rows and 7 columns:

Amendment

Name of the amendment

DMC

Dry matter content of the amendment [gDM/kgFM]

OM

Organic matter content of the amendment, relative to its fresh weight [gDM/kgFM]

C_content

Carbon content of the amendment, relative to its dry matter [gC/kgDM]

N_tot

Total N conent of the amendment, relative to it's dry fresh weight [gN/kgFM]

N_content

Nitrogen content of the amendment, relative to its dry matter [gN/kgDM]

Comment

Comment, e.g. source of the information. These lines are shown as part of the function output

References

Compilation of Values from the SoilX project. Please check the `CN_input_amendments_LUT.xlsx` file under `/inst/extdata/` for more information

GRUD2017_ch8SoilManageR

GRUD2017_ch4SoilManageR