| C_input | R Documentation |
C_input() estimates the carbon (C) input into the soil system per year of a
management_df.
C_input(var_MGMT_data, extended.output = FALSE)
var_MGMT_data |
a |
extended.output |
an optional logical value.
|
The function takes a management_df as input and returns
a C input values per year in the management_df.
Alternatively, it can return a tibble with all managememnt operations and their respective C input values.
The functions calculates the C input with the C_input_crops(),
C_input_cover_crops() and CN_input_amendments() functions.
By default, a tibble with C input values (total and by category) by year is returned.
If extended.output = TRUE, a tibble with all management operations and their
respecitve C inputs is returned.
calculate_indicators() to calculate all management indicators
for a management_df
calculate_C_input_tibble() a helper function that calculates the C input tibble
C_input_crops() to calculate C input for crops
C_input_cover_crops() to calculate C input for cover crops
CN_input_amendments() to calculate C (and N) inputs for organic amendments
#example that returns annual C input values
C_input(EXAMPLE_data)
#example that returns a tibble with all operations that have a C input
C_input(EXAMPLE_data, extended.output = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.