C_input_cover_crops() internally calls C_input_crops() to calculate the
different C fractions. The C in the above ground biomass (\(C_{Product}\))
is a function of the time a cover crop is established. A minimum and
a maximum cover crop biomass are assumed at 180 and 240 days respectively,
and linearly interpolated for the period in between.
$$C_{Product} = \begin{cases}
1253\ kgC/ha \ , \ duration < 180 \ days \\
1253 \ kgC/ha \ + \ (duration - 180 \ days) \ * \frac{663 \ kgC/ha}{60 \ days} \ , \ 180 \ days \leq duration \leq 240 \ days \\
1916 \ kgC/ha \ , \ duration > 240 \ days
\end{cases}$$
Assumptions on the C inputs at day 180 and 240 are based on values
extracted from seitz2022;textualSoilManageR.
The remaining parameters to calculate the C input by cover crops are
HI = 1, SER = 3.67, and REF = 0.31, all derived from seitz2022;textualSoilManageR.
Note, that with these assumptions the C input of short term cover crops
(e.g. few weeks) is overestimated.
The function C_input_cover_crops() estimates the C input by applying the
assumptions mentioned above. Alternatively, the user can
supply an above ground biomass and a CC of the biomass,
or other parameters to estimate the C input by cover crops.