| C_input_crops_LUT | R Documentation |
The data set is a look-up-table that is used to calculate the C inputs by crops with the Bolinder formula, that is implemented in the function 'SoilManageR::C_input_crops()'. The data set is produced from the excel table 'C_input_crops_LUT.xlsx' file under '/inst/extdata/'.
C_input_crops_LUT
A tibble with 28 rows and 19 columns:
Name of the crop
Ratio of the C in the product to the total carbon that is allocated by the plant (in a year)
Ratio of the C in the above ground residues (e.g. straw) to the total carbon that is allocated by the plant (in a year)
Ratio of the C in the plant roots to the total carbon that is allocated by the plant (in a year)
Ratio of the C in the root exudates to the total carbon that is allocated by the plant (in a year)
Proportion of the C in the Product that is transfered to the soil
Proportion of the C in the above ground residues (e.g. straw) that is transfered to the soil
Proportion of the C in the roots that is transfered to the soil
Proportion of the C in root exudates that is transfered to the soil
Reference yield, derived from the Swiss fertilizer recommendations (GRUD, 2017, Chapters 8 and 9) [tDM/ha]
Ratio of the product to the total of the product and the above ground residues. Calculated by RP/(RP+RS) (assuming all biomass has 45% C)
Logical value, if the variable harvest index assumption of Fan et al. (2017) are to be aplied or not.
Intercept of the variable harvest index assumption of Fan et al. (2017) are to be aplied.
Slope of the variable harvest index assumption of Fan et al. (2017) are to be aplied. [ha/tDM]
Ratio of the product and the above ground residues to the root biomass. Calculated by (RP+RS)/RR (assuming all biomass has 45% C)
Ratio of the root exudates to the root biomass. Calculated by RE/RR (assuming all biomass has 45% C)
Logical value if the fixed below ground C allocation assumption of Taghizadeh-Toosi et al. (2020) is to be applied or not.
Fixed value of root carbon input that is to be assumed. [kgC/ha]
Source where the information was derived.
Compilation of values from the SoilX project. Please check the 'C_input_crops_LUT.xlsx' file under '/inst/extdata/' for more information.
\insertRefbolinder2007SoilManageR
\insertRefbolinder2015SoilManageR
\insertReffan2017SoilManageR
\insertRefhirte2018SoilManageR
\insertRefkeel2017SoilManageR
\insertRefseitz2022SoilManageR
\insertRefGRUD2017_ch8SoilManageR
\insertReftaghizadeh-toosi2020SoilManageR
\insertRefwuest2020SoilManageR
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.