| N_input | R Documentation |
This function estimates the nitrogen (N) input by mineral and organic fertilization into the soil system per year.
N_input(var_MGMT_data, extended.output = FALSE)
var_MGMT_data |
a |
extended.output |
an optional logical value:
|
The function takes a management_df as input and returns N input values
per year in the management_df.
Alternatively, it can return a extensive tibble with all management operations and their N input values.
The functions calculates the N input by
organic fertilization with the calculate_N_input_tibble() and the
CN_input_amendments() function.
Furthermore, it calculates the livestock intensity (LSU/ha) by deviding
the animal derived N by 105kgN/LSU.
Be aware that the function currently neglects N that is fixated by plants (e.g. legumes)
by default, a tibble with N input values (organic N, mineral N and total N) by year is returned. If extended.output = TRUE, a tibble with daily resolution is returned.
calculate_indicators() to calculate all management indicators
for a management_df
CN_input_amendments() for the calculation of N inputs from organic amendments
calculate_N_input_tibble() a helper function that calculates the N input tibble
calculate_indicators() to calculate all management indicators
for a management_df
CN_input_amendments() for the calculation of N inputs from organic amendments
calculate_N_input_tibble() a helper function that calculates the N input tibble
#example that returns annual N input values
N_input(EXAMPLE_data)
#example that returns a tibble with all management operations and their N input
N_input(EXAMPLE_data, extended.output = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.