View source: R/calculate_STIR_tibble.R
| calculate_STIR_tibble | R Documentation |
A function that calculates the STIR value of all operations in a management_df.
The output is returned as a tibble.
calculate_STIR_tibble(var_MGMT_data)
var_MGMT_data |
a |
The function is mainly a helper function for the tillage_intensity() function.
a tibble with all management operations and STIR values
STIR() for the calculation of a STIR value for operations
STIR_values_LUT() for the reference data used for tillage operations
calculate_indicators() to calculate all management indicators
for a management_df
tillage_intensity() aggregates the STIR values
#example that returns a tibble with all operations that have a STIR value
calculate_STIR_tibble(EXAMPLE_data)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.