Learn R Programming

SoilManageR (version 1.0.1)

filter_management_df: Filter management_df for pattern in comments

Description

Excludes operations (lines) from management_df based on a character pattern in the comments column.

Usage

filter_management_df(var_MGMT_data, filter_pattern)

Value

a filtered management_df

Arguments

var_MGMT_data

management_df

filter_pattern

string based on which the lines should be excluded

Examples

Run this code
# filter EXAMPLE_data and exclude all lines that contain "UFA 330" in comments
filter_management_df(EXAMPLE_data,"UFA 330")

Run the code above in your browser using DataLab