This function is a constructor for empty objects of the management_df() class,
the core of the SoilManageR package.
management_df(
crop = NA,
year = NA,
date = NA,
category = NA,
operation = NA,
device = NA,
value = NA,
unit = NA,
machine = NA,
product = NA,
combination = NA,
comments = NA,
DMC = NA,
C_content = NA,
N_content = NA,
crop_product = NA,
crop_residue = NA,
Cc_product = NA,
Cc_residue = NA
)a management_df()
Name of the main crop. Must match a pre-existing list
Year of the management operation ("YYYY")
Date of the management operation ("YYYY-MM-DD")
Categorization of the managment operation (1 level). Must match a pre-existing list.
Categorization of the managment operation (2 level). Must match a pre-existing list.
Categorization of the managment operation (3 level). Must match a pre-existing list.
Numerical value linked to managment operation (e.g., depth of tillage operation, mass of organic amendment)
Unit of the numerical value (e.g. cm, t/ha)
Further information on the machine used (e.g., type, manufacturer, tool)
Further information on the applied product (e.g., name, manufacturer). Must match pre-existing list for organic amendments.
Indicate if a operation was done in combination with others. Use consequtive integer numbers if combinded operations occur. Leave empty if not combined.
Comments related to the management operation
Dry matter content of organic amendments (gDM/kgFM)
Carbon content of the amendments, relative to its dry matter (gC/kgDM)
Nitrogen content of organic amendments, relative to its dry matter (gN/kgDM)
Crop product yield (tDM/ha)
Crop residue mass (tDM/ha)
Carbon content of the crop product (gC/kgDM)
Carbon content of the crop residue (gC/kgDM)
management_df_from_excel() for importing a management_df from an excel template
check_management_df() to check the integrity of a management_df
EXAMPLE_data() for an example of a management_df
#creation of an empty management_df
management_df()
Run the code above in your browser using DataLab