Learn R Programming

SoilManageR (version 1.0.1)

plant_cover: Estimate soil cover percentage by plants

Description

This function estimates the percentage of soil cover based on the number of days since sowing. The parameters used are derived from mosimann2006;textualSoilManageR.

Usage

plant_cover(varCrop, varDays = 0)

Value

percentage of soil cover by plants, value of 0 to 100 %.

Arguments

varCrop

Crop type, must match with crop name in plant_cover_LUT

varDays

Number of days since sowing of the crop

Details

The function assumes that plant cover unfolds in four phases with different soil cover rates:

  • 0 to 10 % of soil cover

  • 10 to 50 % of soil cover

  • 50 to 75 % of soil cover

  • 75 to 100 % of soil cover

References

See Also

  • soil_cover() to calculate soil coverage by plants and residue for a management_df

  • plant_cover_LUT() for the data used by the plant_cover() function

Examples

Run this code
plant_cover("wheat, winter", 140)


Run the code above in your browser using DataLab