soil_cover: Estimate soil cover by plants and residues

View source: R/soil_cover.R

soil_coverR Documentation

Estimate soil cover by plants and residues

Description

Derives the days where soil cover by living plants or resiudes is ⁠>=30%⁠.

Usage

soil_cover(var_MGMT_data, extended.output = FALSE)

Arguments

var_MGMT_data

a management_df that contains the management information

extended.output

an optional logical value.

  • If FALSE, soil cover days are aggregated by year.

  • If TRUE, a soil_cover_tibble with daily resolution is returned.

  • Default value is FALSE

Details

The function takes a management_df as input and returns soil cover days per year in the management_df. Alternatively, it can return a soil_cover_tibble with daily resolution of the estimated soil cover.

The function calculates plant soil cover with the plant_cover() function and the soil coverage by residues.

The residue mass is dependent on the residue supply by crops, its decay and its incorporation by tillage operations \insertCitebuchi2016SoilManageR.

Residue supply is estimated with the yield dependent residue C C_input_straw provided by the function C_input_crops() and a C content of 450 \ [mgC/gDM]. If residues are removed, the removed residue mass is subtracted.

Residue decay is calculated with the formula of \insertCitesteiner1999;textualSoilManageR:

M_t = M_{t-1} * (1 - k_{decay})

Where M_{t-1} is the residue mass of the prior day [g/m^2] and k_{decay} is the daily decay rate that was assumed to be 0.028 g/g, the average decomposition rate of winter wheat straw \insertCitesteiner1999SoilManageR.

Residue incorporation by tillage was estimated with the operation-specific burial coefficient extracted from the RUSLE2 database \insertCiteRUSLE2SoilManageR that are provided in the look-up-table STIR_values_LUT.

Residue mass is translated into percentage of soil cover by the formula of \insertCitesteiner2000;textualSoilManageR:

cover_{residues} = (1-e^{-k(M)})* 100 \%

Where M is the residue mass [g/m^2] and k is a cover coefficient [m^2/g]. k was assumed to be 0.0175 \insertCitesteiner2000SoilManageR.

Value

  • By default, a tibble with soil cover days by year is returned.

  • If extended.output = TRUE, an object of the class soil_cover_tibble with daily resolution is returned.

References

\insertAllCited

See Also

  • calculate_indicators() to calculate all management indicators for a management_df

  • calculate_soil_cover_tibble() a helper function that calculates the soil cover tibble

  • plant_cover() for more detail on the plant cover function

  • plot.soil_cover_tibble() for plotting the soil_cover_tibble

  • STIR_values_LUT for tillage operation specific burial coefficients

Examples


  #example that returns annual soil cover days by plants and residues
  soil_cover(EXAMPLE_data)

  #example that returns a soil_cover_tibble
  soil_cover(EXAMPLE_data, extended.output = TRUE)



SoilManageR documentation built on June 8, 2025, 9:36 p.m.