Learn R Programming

SoilManageR (version 1.0.1)

tillage_intensity: Estimate tillage intensity

Description

Calculates the soil tillage intensity per year. The function takes a management_df as input and returns a STIR value per year in the management_df. Alternatively, it can return a extensive tibble with each operation and their respective STIR values.

Usage

tillage_intensity(var_MGMT_data, extended.output = FALSE)

Value

by default, a tibble with STIR values by year is returned. If extended.output = TRUE, a tibble with daily resolution is returned.

Arguments

var_MGMT_data

a management_df that contains the management information

extended.output

an optional logical value. Default value is FALSE

  • If FALSE, STIR values are aggregated by year.

  • If TRUE, a tibble with all management operations is returned.

See Also

  • STIR() for the calculation of a STIR value for operations

  • STIR_values_LUT() for the reference data used for tillage operations

  • calculate_indicators() to calculate all management indicators for a management_df

Examples

Run this code
#example that returns annual STIR values
tillage_intensity(EXAMPLE_data)

#example that returns a tibble with all operations that have a STIR value
tillage_intensity(EXAMPLE_data, extended.output = TRUE)

Run the code above in your browser using DataLab