The dataset is a look-up-table that is used to calculate the carbon (C) and nitrogen (N) inputs by organic amendments with the function `SoilManageR::CN_input_amendments()`. The data set is produced from the excel table `CN_input_amendments_LUT.xlsx` file under `/inst/extdata/`.
CN_input_amendments_LUTA tibble with 27 rows and 7 columns:
Name of the amendment
Dry matter content of the amendment [gDM/kgFM]
Organic matter content of the amendment, relative to its fresh weight [gDM/kgFM]
Carbon content of the amendment, relative to its dry matter [gC/kgDM]
Total N conent of the amendment, relative to it's dry fresh weight [gN/kgFM]
Nitrogen content of the amendment, relative to its dry matter [gN/kgDM]
Comment, e.g. source of the information. These lines are shown as part of the function output
Compilation of Values from the SoilX project. Please check the `CN_input_amendments_LUT.xlsx` file under `/inst/extdata/` for more information
GRUD2017_ch8SoilManageR
GRUD2017_ch4SoilManageR