The annual C input by crops were estimated based on crop type and crop yield
with the allometric functions of bolinder2007;textualSoilManageR:
$$
C_{Product} = Product * CC_{Product}
$$
$$
C_{Straw} = {Product}* \frac{1 - HI}{HI} * CC_{Straw}
$$
$$
C_{Root} = \frac{Product}{SRR*HI} * CC_{Root}
$$
$$
C_{Exudates} = C_{Root} * REF
$$
Where \(C\) is the C per fraction (in kgC/ha) and \(CC\) is the C
content of given fraction (kgC/tDM). \(Prodcuct\) is the dry matter
yield of a crop in tDM/ha, \(HI\) is the harvest index
(ratio of product total of product and straw), \(SRR\) is the
ratio of the shoot biomass (product and straw) to the root biomass,
and \(REF\) is the root exudation factor
(i.e., the ratio of the C exudated by the roots
to the C in the root biomass). All fractions are multiplied with
a crop and fraction specific \(S\)-factor that determines the share
of the fraction that is returned to the soil.
If not mentioned otherwise parameters were taken from the
publications of bolinder2007;textualSoilManageR,
keel2017;textualSoilManageR or
wuest2020;textualSoilManageR.
Parameters for potatoes and sugar beets were derived from
bolinder2015;textualSoilManageR
For temporary leys we assumed yield-independent annual
\(C_{Root}\) of 1.5 MgC/ha and a \(REF\) of 0.5
taghizadeh-toosi2020SoilManageR.
Furthermore, like wuest2020;textualSoilManageR, the
belowground C input (\(C_{Root} + C_{Exudates}\)) of corn maize,
silage maize and cereals were fixed to 0.46 MgC/ha, 1.1 MgC/ha and
0.6 MgC/ha respectively, based on the values from
hirte2018;textualSoilManageR.
Additionally, we applied the yield dependent harvest index
\((HI = Intercept + Product * Slope)\) proposed by
fan2017;textualSoilManageR for cereals, faba beans,
peas, corn, rapeseed, and soybeans.
Reference yields were derived from the Swiss fertilizer recommendations
GRUD2017_ch8;textualSoilManageR.
All default values can be found in the look-up-table C_input_crops_LUT.