Learn R Programming

SoilManageR (version 1.0.1)

C_input_crops_LUT: Look-up-table with default values to calculate carbon (C) inputs by crops

Description

The data set is a look-up-table that is used to calculate the C inputs by crops with the Bolinder formula, that is implemented in the function `SoilManageR::C_input_crops()`. The data set is produced from the excel table `C_input_crops_LUT.xlsx` file under `/inst/extdata/`.

Usage

C_input_crops_LUT

Arguments

Format

A tibble with 28 rows and 19 columns:

Crop

Name of the crop

RP

Ratio of the C in the product to the total carbon that is allocated by the plant (in a year)

RS

Ratio of the C in the above ground residues (e.g. straw) to the total carbon that is allocated by the plant (in a year)

RR

Ratio of the C in the plant roots to the total carbon that is allocated by the plant (in a year)

RE

Ratio of the C in the root exudates to the total carbon that is allocated by the plant (in a year)

SP

Proportion of the C in the Product that is transfered to the soil

SS

Proportion of the C in the above ground residues (e.g. straw) that is transfered to the soil

SR

Proportion of the C in the roots that is transfered to the soil

SE

Proportion of the C in root exudates that is transfered to the soil

crop_product

Reference yield, derived from the Swiss fertilizer recommendations (GRUD, 2017, Chapters 8 and 9) [tDM/ha]

harvest_index

Ratio of the product to the total of the product and the above ground residues. Calculated by RP/(RP+RS) (assuming all biomass has 45% C)

varible_harvest_index

Logical value, if the variable harvest index assumption of Fan et al. (2017) are to be aplied or not.

HI_intercept

Intercept of the variable harvest index assumption of Fan et al. (2017) are to be aplied.

HI_slope

Slope of the variable harvest index assumption of Fan et al. (2017) are to be aplied. [ha/tDM]

shoot_root_ratio

Ratio of the product and the above ground residues to the root biomass. Calculated by (RP+RS)/RR (assuming all biomass has 45% C)

root_exudation_factor

Ratio of the root exudates to the root biomass. Calculated by RE/RR (assuming all biomass has 45% C)

fixed_belowground_input

Logical value if the fixed below ground C allocation assumption of Taghizadeh-Toosi et al. (2020) is to be applied or not.

C_input_root

Fixed value of root carbon input that is to be assumed. [kgC/ha]

Source where the information was derived.

References

Compilation of values from the SoilX project. Please check the `C_input_crops_LUT.xlsx` file under `/inst/extdata/` for more information.

bolinder2007SoilManageR

bolinder2015SoilManageR

fan2017SoilManageR

hirte2018SoilManageR

keel2017SoilManageR

seitz2022SoilManageR

GRUD2017_ch8SoilManageR

taghizadeh-toosi2020SoilManageR

wuest2020SoilManageR