powered by
Excludes operations (lines) from management_df based on a character pattern in the comments column.
filter_management_df(var_MGMT_data, filter_pattern)
a filtered management_df
management_df
string based on which the lines should be excluded
# filter EXAMPLE_data and exclude all lines that contain "UFA 330" in comments filter_management_df(EXAMPLE_data,"UFA 330")
Run the code above in your browser using DataLab