Derives three indicators for plant diversity of a crop rotation based on management information (mainly sowing events).
plant_diversity(var_MGMT_data, start_year, end_year)a tibble with three indicators for plant diversity
a 'management_df' with a management history
start year of the cropping sequence of interest
end year of the cropping sequence of interest
For the function to work properly the species (or variety) must be mentioned
in the "product" column, and all sown species of mixtures must be
represented in a single row of the management_df each.
The function calculates the plant diversity index (\(PDI\)), the total number of different species, and the Shannon index for all sown species.
The \(PDI\) is calculated in the following way inspired by Tiemann_2015;textualSoilManageR: $$PDI = \overline{S_{year}} * S_{rotation}$$ where \(\overline{S_{year}}\) is the average number of sown species per year and \(S_{rotation}\) is the total number of different species sown in the full crop rotation or cropping sequence.
The Shannon Index is calculated with the shannon_index() function.
calculate_indicators() to calculate all management indicators
for a management_df
shannon_index() for more detail on the Shannon index
plant_diversity(EXAMPLE_data,2013,2020)
Run the code above in your browser using DataLab