This function calculates the relative yield of an observed
dry matter yield compared to the reference dry matter yield
in the Swiss fertilizing guidelines GRUD2017_ch8SoilManageR.
Usage
relative_yield(var_crop, var_yield)
Value
the numeric value for the relative yield
Arguments
var_crop
string with name of crop type,
must match with the Crops in the C_input_crops_LUT
var_yield
observed dry matter yield (tDM/ha)
References
See Also
productivity_indicator() to calculate relative yields for a management_df
C_input_crops_LUT() for reference yield used in the relative_yield() function